from flask import Flask, render_template, url_for, jsonify, request
import os.path
import graph
import coin
import utils
app = Flask(__name__)

@app.route('/')
@app.route('/<withdrawal_address>')
def index(withdrawal_address=None):
    force = request.args.get('force', None)
    slush_head_address = None
    if withdrawal_address is not None:
        slush_head_address = coin.find_slush_head(withdrawal_address)
        filepath = "data/slushfund-%s.json" % (slush_head_address)
        if force is not None or not os.path.isfile(filepath):
            filepath = url_for('analyze', slush_head_address=slush_head_address)
        else:
            filepath = url_for('static', filename=filepath)
    else:
        filepath = None

    return render_template('index.html', filepath=filepath, address=withdrawal_address, slush_head_address=slush_head_address)

@app.route('/analyze/<slush_head_address>')
def analyze(slush_head_address):
    G = coin.chain_analyze_bitcoinfog(slush_head_address, 1000)
    return jsonify(graph.export_json(G, 'data/slushfund-%s.json' % (slush_head_address)))

@app.route('/benford_law/<slush_head_address>')
def benford_law(slush_head_address):
    G = coin.chain_analyze_bitcoinfog(slush_head_address, 1000)
    sizes = coin.get_sizes_from_graph(G)
    if len(sizes) == 0:
        return jsonify({})
    first_digits = coin.get_digit_distribution(sizes)
    second_digits = coin.get_second_digit_distribution(sizes)
    return jsonify({'first': first_digits, 'second': second_digits})

@app.route('/withdrawal_analysis/<slush_head_address>')
def withdrawal_analysis(slush_head_address):
    G = coin.chain_analyze_bitcoinfog(slush_head_address, 1000)
    H = coin.extend_withdrawal_graph(G)
    graph.graph_withdrawal(H)
    results = utils.bfs_tree(H, 'start')
    return jsonify(results)

if __name__ == '__main__':
    app.run(debug=True)
