/* globals d3 */

var w = 14000,
    h = 440;

d3.selection.prototype.moveToFront = function () {
  return this.each(function (){
    this.parentNode.appendChild(this);
  });
};

function graph(filepath) {

  var vis = d3.select("#chart")
    .append("svg:svg")
    .attr("width", w)
    .attr("height", h);

  function onImport(json) {
    var force = d3.layout.force()
        .charge(-120)
        .linkDistance(30)
        .nodes(json.nodes)
        .links(json.links)
        .size([w, h])
        .start();

    var tip = d3.tip()
        .attr('class', 'd3-tip')
        .html(function (d) { return d.type + ':<br><a target="_blank" href="http://blockchain.info/address/' + d.id + '">' + d.id + '</a>'; })
        .direction(function (d) {
          if (d.type == 'start' || d.type === 'slush') {
            return 's';
          } else {
            return 'n';
          }
        });
    vis.call(tip);

    var prev_x = 30;
    var prev_y = 15;
    var node = vis.selectAll('circle.node')
        .data(json.nodes)
        .enter().append('svg:circle')
        .attr('class', 'node')
        .attr('cx', function (d) {
          if (d.type !== 'start') {
            d.x = prev_x + (parseInt(d.order, 10) * 30);
          } else if (d.type === 'start') {
            d.x = 5;
          }
          return d.x;
        })
        .attr('cy', function (d) {
          if (d.type === 'withdrawal') {
            d.y = prev_y + 400;
          } else {
            d.y = prev_y;
          }
          return d.y;
        })
        .attr('r', 6)
        .style('fill', function (d) {
          if (d.type === 'start') {
            return 'red';
          } else if (d.type === 'withdrawal') {
            return 'green';
          }
          return 'blue';
        })
        .on('click', tip.show);

    var link = vis.selectAll('line.link')
        .data(json.links)
        .enter().append('svg:line')
        .attr('class', 'link')
        .style('stroke-width', function () { return 3; })
        .attr('x1', function (d) { return d.source.x; })
        .attr('y1', function (d) { return d.source.y; })
        .attr('x2', function (d) { return d.target.x; })
        .attr('y2', function (d) { return d.target.y; });

    vis.selectAll('circle.node').each(function () {
      var sel = d3.select(this);
      sel.moveToFront();
    });

    /*force.off("tick", function() {
      link.attr("x1", function(d) { return d.source.x; })
          .attr("y1", function(d) { return d.source.y; })
          .attr("x2", function(d) { return d.target.x; })
          .attr("y2", function(d) { return d.target.y; });

    node.attr("cx", function(d) { return d.x; })
        .attr("cy", function(d) { return d.y; });
    });*/

    $('.results').removeClass('hide');
  }

  d3.json(filepath, onImport);
}

function benford(url) {
  function onSuccess(data) {
    $.each(data.first, function (key, value) {
      $('#first_digit').find('.value-' + key).text(value);
    });
    $.each(data.second, function (key, value) {
      $('#second_digit').find('.value-' + key).text(value);
    });
  }

  $.ajax(url, {
    success: onSuccess
  });
}

$(function () {
  $('.form-inline').on('submit', function (event) {
    event.preventDefault();
    var $form = $(this);
    var address = $form.find('input').val();
    var loc = window.location;
    loc.href = loc.origin + loc.pathname.replace(/\/[A-Za-z0-9]*/, '/' + address);
  });
});
